@@ -69,7 +69,7 @@ impl Capacity {
     pub(super) async fn levels(&self) -> BTreeMap<XorName, StorageLevel> {
         let mut map = BTreeMap::new();
         for (name, level) in self.adult_levels.read().await.iter() {
-            let _ = map.insert(*name, *level.read().await);
+            let _prev = map.insert(*name, *level.read().await);
         }
         map
     }
@@ -89,7 +89,7 @@ impl Capacity {
         let mut set = BTreeSet::new();
         for (name, level) in self.adult_levels.read().await.iter() {
             if level.read().await.value() >= MIN_LEVEL_WHEN_FULL {
-                let _ = set.insert(*name);
+                let _changed = set.insert(*name);
             }
         }
         set
@@ -97,7 +97,7 @@ impl Capacity {
 
     pub(super) async fn set_adult_levels(&self, levels: BTreeMap<XorName, StorageLevel>) {
         for (name, level) in levels {
-            let _ = self.set_adult_level(name, level).await;
+            let _changed = self.set_adult_level(name, level).await;
         }
     }
 
@@ -133,7 +133,7 @@ impl Capacity {
             }
             false // no change
         } else {
-            let _ = all_levels.insert(adult, Arc::new(RwLock::new(new_level)));
+            let _level = all_levels.insert(adult, Arc::new(RwLock::new(new_level)));
             info!("New value inserted.");
             true // value changed
         }
@@ -150,7 +150,7 @@ impl Capacity {
             .collect();
 
         for adult in &absent_adults {
-            let _ = adult_levels.remove(adult);
+            let _level = adult_levels.remove(adult);
         }
     }
 }
