@@ -29,6 +29,7 @@ use crate::routing::{
         test_utils::*, NetworkKnowledge, NodeState, SectionAuthorityProvider, SectionKeyShare,
     },
     node::Node,
+    recommended_section_size,
     relocation::{self, RelocatePayloadUtils},
     supermajority, Error, Event, Peer, Result as RoutingResult, UnnamedPeer, FIRST_SECTION_MAX_AGE,
     FIRST_SECTION_MIN_AGE, MIN_ADULT_AGE, MIN_AGE,
@@ -1022,9 +1023,22 @@ enum RelocatedPeerRole {
 
 async fn relocation(relocated_peer_role: RelocatedPeerRole) -> Result<()> {
     let prefix: Prefix = "0".parse().unwrap();
+    let section_size = match relocated_peer_role {
+        RelocatedPeerRole::Elder => elder_count(),
+        RelocatedPeerRole::NonElder => recommended_section_size(),
+    };
     let (section_auth, mut nodes, sk_set) = gen_section_authority_provider(prefix, elder_count());
     let (section, section_key_share) = create_section(&sk_set, &section_auth).await?;
 
+    let mut adults = section_size - elder_count();
+    while adults > 0 {
+        adults -= 1;
+        let non_elder_peer = create_peer(MIN_ADULT_AGE);
+        let node_state = NodeState::joined(non_elder_peer.clone(), None);
+        let node_state = section_signed(sk_set.secret_key(), node_state)?;
+        assert!(section.update_member(node_state).await);
+    }
+
     let non_elder_peer = create_peer(MIN_AGE);
     let node_state = NodeState::joined(non_elder_peer.clone(), None);
     let node_state = section_signed(sk_set.secret_key(), node_state)?;
@@ -1228,7 +1242,7 @@ async fn handle_elders_update() -> Result<()> {
     let sk_set1 = SecretKeySet::random();
 
     let pk1 = sk_set1.secret_key().public_key();
-    // Create `HandleAgreement` command for an `OurElders` proposal. This will demote one of the
+    // Create `HandleAgreement` command for an `NewElders` proposal. This will demote one of the
     // current elders and promote the oldest peer.
     let sap1 = SectionAuthorityProvider::new(
         iter::once(node.peer())
@@ -1240,7 +1254,7 @@ async fn handle_elders_update() -> Result<()> {
     let elder_names1: BTreeSet<_> = sap1.names();
 
     let signed_sap1 = section_signed(sk_set1.secret_key(), sap1)?;
-    let proposal = Proposal::OurElders(signed_sap1);
+    let proposal = Proposal::NewElders(signed_sap1);
     let signature = sk_set0.secret_key().sign(&proposal.as_signable_bytes()?);
     let sig = KeyedSig {
         signature,
@@ -1270,7 +1284,10 @@ async fn handle_elders_update() -> Result<()> {
     let dispatcher = Dispatcher::new(core);
 
     let commands = dispatcher
-        .handle_command(Command::HandleElderAgreement { proposal, sig }, "cmd-id")
+        .handle_command(
+            Command::HandleNewEldersAgreement { proposal, sig },
+            "cmd-id",
+        )
         .await?;
 
     let mut update_actual_recipients = HashSet::new();
@@ -1397,17 +1414,17 @@ async fn handle_demote_during_split() -> Result<()> {
 
     // Create agreement on `OurElder` for both sub-sections
     let create_our_elders_command = |signed_sap| -> Result<_> {
-        let proposal = Proposal::OurElders(signed_sap);
+        let proposal = Proposal::NewElders(signed_sap);
         let signature = sk_set_v0.secret_key().sign(&proposal.as_signable_bytes()?);
         let sig = KeyedSig {
             signature,
             public_key: sk_set_v0.public_keys().public_key(),
         };
 
-        Ok(Command::HandleElderAgreement { proposal, sig })
+        Ok(Command::HandleNewEldersAgreement { proposal, sig })
     };
 
-    // Handle agreement on `OurElders` for prefix-0.
+    // Handle agreement on `NewElders` for prefix-0.
     let section_auth = SectionAuthorityProvider::new(
         peers_a.iter().cloned().chain(iter::once(peer_c)),
         prefix0,
@@ -1420,7 +1437,7 @@ async fn handle_demote_during_split() -> Result<()> {
 
     assert_matches!(&commands[..], &[]);
 
-    // Handle agreement on `OurElders` for prefix-1.
+    // Handle agreement on `NewElders` for prefix-1.
     let section_auth =
         SectionAuthorityProvider::new(peers_b.iter().cloned(), prefix1, sk_set_v1_p1.public_keys());
 
